@@ -1,4 +1,5 @@
-package DBIx::Class::CDBICompat::ColumnCase;
+package # hide from PAUSE
+    DBIx::Class::CDBICompat::ColumnCase;
 
 use strict;
 use warnings;
@@ -10,9 +11,10 @@ sub _register_column_group {
   return $class->next::method($group => map lc, @cols);
 }
 
-sub _register_columns {
+sub add_columns {
   my ($class, @cols) = @_;
-  return $class->next::method(map lc, @cols);
+  $class->mk_group_accessors(column => @cols);
+  $class->result_source_instance->add_columns(map lc, @cols);
 }
 
 sub has_a {
@@ -24,8 +26,8 @@ sub has_a {
 
 sub has_many {
   my ($class, $rel, $f_class, $f_key, @rest) = @_;
-  return $class->next::method($rel, $f_class, ( ref($f_key) ? 
-                                                          $f_key : 
+  return $class->next::method($rel, $f_class, ( ref($f_key) ?
+                                                          $f_key :
                                                           lc($f_key) ), @rest);
 }
 
@@ -78,16 +80,6 @@ sub _mk_group_accessors {
                                                      @fields, @extra);
 }
 
-sub _cond_key {
-  my ($class, $attrs, $key, @rest) = @_;
-  return $class->next::method($attrs, lc($key), @rest);
-}
-
-sub _cond_value {
-  my ($class, $attrs, $key, @rest) = @_;
-  return $class->next::method($attrs, lc($key), @rest);
-}
-
 sub new {
   my ($class, $attrs, @rest) = @_;
   my %att;
